<?php
/**
 * Public Class
 *
 * @package     Wow_Plugin
 * @subpackage  Public
 * @copyright   Copyright (c) 2018, Dmytro Lobov
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
 */

namespace edd_product_faq;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WP_Plugin_Public {

	public function __construct( $info ) {
		$this->plugin = $info['plugin'];

		add_action( 'wp_enqueue_scripts', array( $this, 'include_scripts' ) );
		// Display on the site
		add_filter( 'the_content', array( $this, 'filter_content' ) );

	}

	public function include_scripts () {
		$pre_suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_style( $this->plugin['slug'] . '-front', $this->plugin['url'] . 'assets/style' . $pre_suffix . '.css' );

		wp_enqueue_script( $this->plugin['slug'] . '-front', $this->plugin['url'] . 'assets/script' . $pre_suffix . '.js', array( 'jquery' ), null, true );
    }


	public function filter_content( $content ) {

		global $post;

		if ( is_object( $post ) && $post->post_type != 'download' ) {
			return;
		}

		$post_id = $post->ID;

		$faqs = get_post_meta( $post_id, '_' . $this->plugin['prefix'], false );
		$faq  = '';

		if ( ! empty( $faqs[0] ) ) {
			$count = count( $faqs[0]['title'] );

			$faq .= '<h3 class="title-faq">' . esc_attr__( 'FAQ', $this->plugin['text'] ) . '</h3>'; ?>

			<?php
			if ( $count > 0 ) {
				for ( $i = 0; $i < $count; $i ++ ) {
					$faq .= '<div class="accordion-wrap">
                            <div class="accordion-block">
                                <div class="accordion-title">
                                    <span class="plus">+</span>
                                    <span class="minus">-</span>
                                    <span class="faq-title">' . esc_html( $faqs[0]['title'][ $i ] ) . '</span>
                                </div>
                                <div class="accordion-content">' . wpautop( $faqs[0]['desc'][ $i ] ) . '</div>
                            </div>
                        </div>';
				}
			}
		}

		return $content . $faq;

	}

}
